PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-06-13-11:04:44','2023-06-13-11:07:05',1686647084,1686647225,'month',1,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "02:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "aayaiavi"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "aayaiavi", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(2,'2023-06-13-11:07:05','2023-06-13-11:11:41',1686647225,1686647501,'month',1,2,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a00g/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "02:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "aayaiavi"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "aayaiavi", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a00g/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(3,'2023-06-13-11:11:41','2023-06-13-11:18:43',1686647501,1686647923,'month',1,12,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"EXPID": "a00g", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "marenostrum4", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:01"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante.dkrz.de", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "bb1153", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "b382351"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(4,'2023-06-13-11:18:43','2023-06-13-11:21:14',1686647923,1686648074,'month',1,12,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "02:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(5,'2023-06-13-11:21:14','2023-06-13-11:39:08',1686648074,1686649148,'month',1,0,12,0,6,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi.csc.fi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi.csc.fi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(6,'2023-06-13-11:39:08','2023-06-13-11:43:38',1686649148,1686649418,'month',1,0,12,0,6,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "HOST": "lumi.csc.fi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi.csc.fi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(7,'2023-06-13-11:43:38','2023-06-13-11:46:56',1686649418,1686649616,'month',1,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "HOST": "lumi.csc.fi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi.csc.fi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(8,'2023-06-13-11:46:56','2023-06-13-11:55:08',1686649616,1686650108,'month',1,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi.csc.fi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi.csc.fi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical", "EXECUTABLE": "/usr/bin/env python3"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(9,'2023-06-13-11:55:08','2023-06-13-11:58:49',1686650108,1686650329,'day',1,0,6,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "DEFAULT": {"EXPID": "a04m", "HPCARCH": "Lumi", "CUSTOM_CONFIG": {"POST": "~/platforms.yml", "PRE": "/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/simulation/test-icon.yml,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/parameter/default.yml,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/model/icon/icon.yml,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/model/icon/r2b4.yml,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/applications/dummy/dummy.yml,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/applications/dummy/gsvrequest.yml,/appl/AS/AUTOSUBMIT_DATA/a04m/proj/workflow/conf/applications/dummy/oparequest.yml"}}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "day", "DATELIST": 20200120, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "app-basic-subworkflow", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow.git", "PROJECT_SUBMODULES": ""}, "GSVREQUEST": {"DATE": 20050401, "LEVTYPE": "sfc", "PARAM": "2t", "STEP": 0, "TIME": "0000/to/2300/by/0100"}, "JOBS": {"APP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"OPA": {}}, "FILE": "templates/application.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05"}, "DN": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/dn.sh", "PLATFORM": "Lumi-login", "RUNNING": "chunk", "WALLCLOCK": "00:05"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "OPA": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"DN": {}}, "FILE": "templates/opa.sh", "PLATFORM": "Lumi", "RUNNING": "chunk", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "Lumi-login", "RUNNING": "once", "WALLCLOCK": "00:05"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "OPAREQUEST": {"CHECKPOINT": true, "CHECKPOINT_FILE": "/users/francerou/checkpoint24.pkl", "OUTPUT_FREQ": "daily", "OUT_FILEPATH": "/users/francerou/", "SAVE": true, "STAT": "mean", "STAT_FREQ": "daily", "TIME_STEP": 60, "VARIABLE": "2t"}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"HOST": "levante.dkrz.de", "PARTITION": "interactive", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "TYPE": "slurm", "USER": "b382351"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH -p standard'']", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": 1, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "ahmedroh"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TEMP_DIR": "", "TYPE": "ps", "USER": "ahmedroh"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": "False", "HOST": "bsc", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TEMP_DIR": "", "TYPE": "slurm", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "mn4-cluster", "MAX_WALLCLOCK": "00:55", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TYPE": "slurm", "USER": "dese28247"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/workflow", "PROJECT": {"PROJECT_DESTINATION": "workflow", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APP": "dummy", "ENVIRONMENT": "openmpi", "GRID": "r2b4", "MODEL": "icon", "MODEL_VERSION": null, "PARAMETER": "default", "SIMULATION": "test-icon"}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms.yml"}}');
INSERT INTO experiment_run VALUES(10,'2023-06-13-11:58:49','2023-06-13-12:10:31',1686650329,1686651031,'month',1,0,12,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi.csc.fi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi.csc.fi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical", "EXECUTABLE": "/usr/bin/env python3"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(11,'2023-06-13-12:10:31','2023-06-13-12:10:57',1686651031,1686651057,'month',1,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "aayaiavi"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "aayaiavi", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"EXECUTABLE": "/usr/bin/env python3", "JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(12,'2023-06-13-12:10:57','2023-06-13-12:11:16',1686651057,1686651076,'month',1,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_465000454", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"EXECUTABLE": "/usr/bin/env python3", "JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(13,'2023-06-13-12:11:16','2023-06-13-12:11:46',1686651076,1686651106,'month',1,0,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi-cluster", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi-cluster", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"EXECUTABLE": "/usr/bin/env python3", "JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(14,'2023-06-13-12:11:46','2023-06-13-12:25:52',1686651106,1686651952,'month',1,2,16,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "git"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"EXECUTABLE": "/usr/bin/env python3", "JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(15,'2023-06-13-12:25:52','2023-06-13-14:36:57',1686651952,1686659817,'month',1,2,16,0,0,0,7,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a04h", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 12}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"EXECUTABLE": "#!/usr/bin/env python3", "JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(16,'2023-06-13-14:36:57','2023-06-14-08:50:13',1686659817,1686725413,'month',1,5,5,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"INI": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"REMOTE_SETUP": {}}, "FILE": "templates/ini.sh", "PLATFORM": "LUMI-login", "RUNNING": "member", "WALLCLOCK": "00:30"}, "LOCAL_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {}, "FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}, "REMOTE_SETUP": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SYNCHRONIZE": {}}, "FILE": "templates/remote_setup.sh", "PLATFORM": "LUMI-login", "RUNNING": "once", "WALLCLOCK": "00:30"}, "SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}, "SYNCHRONIZE": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"LOCAL_SETUP": {}}, "FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "RUNNING": "once"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(17,'2023-06-14-08:50:13','2023-06-14-08:50:32',1686725413,1686725432,'month',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(18,'2023-06-14-08:50:32','2023-06-14-08:50:50',1686725432,1686725450,'month',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(19,'2023-06-14-08:50:50','2023-06-14-08:51:09',1686725450,1686725469,'month',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(20,'2023-06-14-08:51:09','2023-06-14-08:51:26',1686725469,1686725486,'month',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 1}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(21,'2023-06-14-08:51:26','2023-06-14-08:53:39',1686725486,1686725619,'month',1,4,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(22,'2023-06-14-08:53:39','2023-06-14-08:58:01',1686725619,1686725881,'month',1,4,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(23,'2023-06-14-08:58:01','2023-06-14-08:59:41',1686725881,1686725981,'month',1,4,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(24,'2023-06-14-08:59:41','2023-06-14-12:41:06',1686725981,1686739266,'month',1,4,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(25,'2023-06-14-12:41:06','2023-06-14-12:41:14',1686739266,1686739274,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(26,'2023-06-14-12:41:14','2023-06-15-11:32:22',1686739274,1686821542,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(27,'2023-06-15-11:32:22','2023-06-22-14:34:23',1686821542,1687437263,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
INSERT INTO experiment_run VALUES(28,'2023-06-22-14:34:23','2023-06-22-14:34:23',1687437263,0,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20}, "CONFIGURATION": {"IFS": {"EXPVER": "hz9m", "GTYPE": "tco", "IO_TASKS": 8, "LABEL": "LWDA", "LEVELS": 137, "NEMO_SERVER_NUM": 8, "RESOL": 79, "XPROC": 12, "YPROC": 4}}, "DEFAULT": {"CUSTOM_CONFIG": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/", "EXPID": "a00g", "HPCARCH": "LUMI"}, "EXPERIMENT": {"CALENDAR": "standard", "CHUNKSIZE": 1, "CHUNKSIZEUNIT": "month", "DATELIST": 19900101, "MEMBERS": "fc0", "NUMCHUNKS": 4}, "GIT": {"FETCH_SINGLE_BRANCH": true, "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/digital-twins/de_340/workflow", "PROJECT_SUBMODULES": "ifs-nemo"}, "JOBS": {"SIM": {"ADDITIONAL_FILES": [], "DEPENDENCIES": {"SIM-1": {}}, "FILE": "templates/sim_ifs-nemo.sh", "PLATFORM": "LUMI", "RETRIALS": 5, "RUNNING": "chunk", "WALLCLOCK": "00:20"}}, "MODEL": {"BRANCH": "RAPS_de340", "NAME": "ifs-nemo", "SOURCE": "https://git.ecmwf.int/scm/~naih/raps.git"}, "PARAMETER": {"RADIATION_FACTOR": 5}, "PLATFORMS": {"JUWELS": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "#SBATCH -p standard -N 1 --ntasks-per-node=24 --cpus-per-task=2", "HOST": "juwels-cluster", "MAX_WALLCLOCK": "48:00", "PARTITION": "devel", "PROCESSORS_PER_NODE": 24, "PROJECT": "hhb19", "QUEUE": "", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<USER>"}, "JUWELS-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "juwels-cluster", "PROJECT": "hhb19", "SCRATCH_DIR": "/p/scratch", "SCRATCH_PROJECT_DIR": "chhb19", "TEMP_DIR": "", "TYPE": "ps", "USER": "<USER>"}, "LEVANTE": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "<to-be-overloaded-by-user>", "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "MAX_WALLCLOCK": "48:00", "PARTITION": "compute", "PROCESSORS_PER_NODE": 128, "PROJECT": "<to-be-overloaded-by-user>", "QUEUE": "", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "slurm", "USER": "<to-be-overloaded-in-user-conf>"}, "LEVANTE-LOGIN": {"ADD_PROJECT_TO_HOST": false, "EXECUTABLE": "/usr/bin/bash -l", "HOST": "levante", "PROJECT": "<to-be-overloaded-by-user>", "SCRATCH_DIR": "/work", "TEMP_DIR": "", "TYPE": "ps", "USER": "<to-be-overloaded-in-user-conf>"}, "LUMI": {"ADD_PROJECT_TO_HOST": false, "BUDGET": "project_465000454", "CUSTOM_DIRECTIVES": "[''#SBATCH --exclude=nid001688,nid001689,nid001785,nid001786,nid001787,nid001569,nid001571,nid001759,nid001763,nid001764,nid001659,nid001665,nid001981,nid001377,nid001682,nid001869,nid001424,nid001876,nid001578,nid001579,nid001357,nid001607,nid001478,nid001622,nid001624,nid001324,nid001331,nid001332,nid001835,nid001837,nid001839,nid001931,nid001935,nid001936,nid001937,nid001939,nid001950,nid001951,nid001952,nid001956,nid001599,nid001600,nid001601,nid001896,nid001502,nid001503,nid001504,nid001593,nid001908,nid001909,nid001968,nid001969,nid001435,nid001451,nid001924,nid001927,nid001728,nid001828,nid001431,nid001845,nid001057,nid001061,nid001190,nid001191,nid001341,nid001342,nid001638,nid001053,nid001445,nid001446,nid001549,nid001089,nid002009,nid001062,nid001284,nid001071,nid001068,nid001738,nid001740'', ''#SBATCH --exclusive'', ''#SBATCH --export=ALL'', ''#SBATCH --hint=nomultithread'']", "EXECUTABLE": "/bin/bash --login", "HOST": "lumi", "MAX_WALLCLOCK": "02:00", "NODES": 3, "PARTITION": "standard", "PROCESSORS": 48, "PROCESSORS_PER_NODE": 128, "PROJECT": "project_462000048", "QUEUE": "", "SCRATCH_DIR": "/scratch", "TASKS": 16, "TEMP_DIR": "", "THREADS": 8, "TYPE": "slurm", "USER": "dbeltran"}, "LUMI-LOGIN": {"ADD_PROJECT_TO_HOST": false, "HOST": "lumi", "NODES": 1, "PARTITION": "debug", "PROCESSORS": 48, "PROJECT": "project_462000048", "SCRATCH_DIR": "/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dbeltran", "WALLCLOCK": "00:30"}, "MARENOSTRUM4": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "PARTITION": "debug", "PROCESSORS": 1024, "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TEMP_DIR": "", "TYPE": "slurm", "USER": "dese28562"}, "MARENOSTRUM4-LOGIN": {"ADD_PROJECT_TO_HOST": false, "CUSTOM_DIRECTIVES": "[''#SBATCH --export=ALL'', ''#SBATCH --exclusive'', ''#SBATCH -n 48'']", "HOST": "mn4-cluster1", "MAX_WALLCLOCK": "00:55", "NODES": 1, "PARTITION": "debug", "PROJECT": "dese28", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "TASKS": 48, "TYPE": "slurm", "USER": "dese28562"}}, "PROJDIR": "/home/dbeltran/new_autosubmit/a00g/proj/git_project", "PROJECT": {"PROJECT_DESTINATION": "git_project", "PROJECT_TYPE": "none"}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a00g", "RUN": {"APPLICATION": "none", "ENVIRONMENT": "cray2", "GRID_ATM": "tco79l137", "GRID_OCEAN": "eORCA1_Z75", "MODEL": "ifs-nemo", "MODEL_VERSION": "dev-aina", "PARAMETER": "default", "SIMULATION": "test-ifs-nemo"}, "SIMULATION": {"CLIMATE_RESTART": "none", "FORCING": "none", "ICMCL": "ICMCL_79_1990", "OCEAN_RESTART": "none", "TYPE": "coupled"}, "STORAGE": {}, "WRAPPERS": {"WRAPPER": {"JOBS_IN_WRAPPER": "SIM", "TYPE": "vertical"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/appl/AS/AUTOSUBMIT_DATA/a04h/proj/git_project/conf/bootstrap/"}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a00g_LOCAL_SETUP','2023-06-13-11:10:06','2023-06-13-11:20:40',1686647406,1686647406,1686647411,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',23016,'',0,2,0.0,0.0,'a00g_LOCAL_SETUP.20230613111018.out','a00g_LOCAL_SETUP.20230613111018.err',5,'a00g_SYNCHRONIZE','');
INSERT INTO job_data VALUES(2,0,'a00g_SYNCHRONIZE','2023-06-13-11:10:18','2023-06-13-12:12:37',1686647418,1686647418,1686647423,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',23052,'',0,2,0.0,0.0,'a00g_SYNCHRONIZE.20230613111030.out','a00g_SYNCHRONIZE.20230613111030.err',5,'a00g_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,0,'a00g_19900101_fc0_1_SIM','2023-06-13-11:12:58','2023-06-13-11:44:03',1686647514,1686647544,1686647549,'COMPLETED',16866472609268,1,'00:01','debug',7030,'1990-01-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',2,'a00g_19900101_fc0_2_SIM',replace('                 28971594  COMPLETED          1        1 2023-06-13T11:11:54 2023-06-13T11:12:19 2023-06-13T11:13:25         14.06K                                                     \n           28971594.batch  COMPLETED          1        1 2023-06-13T11:12:19 2023-06-13T11:12:19 2023-06-13T11:13:25         14.03K                     5324K                     5324K \n          28971594.extern  COMPLETED          1        1 2023-06-13T11:12:19 2023-06-13T11:12:19 2023-06-13T11:13:25         14.06K                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(4,0,'a00g_19900101_fc0_2_SIM','2023-06-13-11:13:18','2023-06-14-08:52:53',1686647514,1686647549,1686647554,'COMPLETED',16866472609268,1,'00:01','debug',7030,'1990-01-01 00:00:00','SIM','fc0',2,0,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_3_SIM','');
INSERT INTO job_data VALUES(5,0,'a00g_19900101_fc0_3_SIM','2023-06-13-11:13:36','2023-06-14-08:52:53',1686647514,1686647554,1686647559,'COMPLETED',16866472608013,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',3,0,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_4_SIM','');
INSERT INTO job_data VALUES(6,0,'a00g_19900101_fc0_4_SIM','2023-06-13-11:13:54','2023-06-14-08:52:52',1686647514,1686647559,1686647564,'COMPLETED',16866472608013,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',4,0,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_5_SIM','');
INSERT INTO job_data VALUES(7,0,'a00g_19900101_fc0_7_SIM','2023-06-13-11:13:54','2023-06-13-11:13:54',1686647514,1686647574,1686647579,'COMPLETED',16866472609182,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',7,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_8_SIM','');
INSERT INTO job_data VALUES(8,0,'a00g_19900101_fc0_8_SIM','2023-06-13-11:13:54','2023-06-13-11:13:54',1686647514,1686647579,1686647584,'COMPLETED',16866472609182,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',8,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_9_SIM','');
INSERT INTO job_data VALUES(9,0,'a00g_19900101_fc0_9_SIM','2023-06-13-11:13:54','2023-06-13-11:13:55',1686647514,1686647584,1686647589,'COMPLETED',16866472608870,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',9,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_10_SIM','');
INSERT INTO job_data VALUES(10,0,'a00g_19900101_fc0_5_SIM','2023-06-13-11:13:55','2023-06-13-11:13:55',1686647514,1686647564,1686647569,'COMPLETED',16866472609211,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',5,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_6_SIM','');
INSERT INTO job_data VALUES(11,0,'a00g_19900101_fc0_11_SIM','2023-06-13-11:13:55','2023-06-13-11:13:55',1686647514,1686647594,1686647599,'COMPLETED',16866472607852,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',11,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_12_SIM','');
INSERT INTO job_data VALUES(12,0,'a00g_19900101_fc0_6_SIM','2023-06-13-11:13:55','2023-06-13-11:13:55',1686647514,1686647569,1686647574,'COMPLETED',16866472609211,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',6,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'a00g_19900101_fc0_7_SIM','');
INSERT INTO job_data VALUES(13,0,'a00g_19900101_fc0_12_SIM','2023-06-13-11:13:55','2023-06-13-11:13:55',1686647514,1686647599,1686647605,'COMPLETED',16866472607852,1,'00:01','debug',0,'1990-01-01 00:00:00','SIM','fc0',12,1,'MARENOSTRUM4',28971594,'',0,3,0.0,0.0,'','',5,'','');
INSERT INTO job_data VALUES(14,1,'a00g_LOCAL_SETUP','2023-06-13-11:20:40','2023-06-13-12:11:52',1686648040,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',23711,'',0,4,0.0,0.0,'','',0,'a00g_SYNCHRONIZE','');
INSERT INTO job_data VALUES(15,1,'a00g_19900101_fc0_1_SIM','2023-06-13-11:44:03','2023-06-13-12:26:17',1686649071,0,0,'READY',16866480755222,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,0,'LUMI',0,'',0,7,0.0,0.0,'','',0,'a00g_19900101_fc0_2_SIM','');
INSERT INTO job_data VALUES(16,2,'a00g_LOCAL_SETUP','2023-06-13-12:11:52','2023-06-13-14:39:18',1686651112,1686651112,1686651112,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',26298,'',0,14,0.0,0.0,'a00g_LOCAL_SETUP.20230613121236.out','a00g_LOCAL_SETUP.20230613121236.err',5,'a00g_SYNCHRONIZE','');
INSERT INTO job_data VALUES(17,2,'a00g_SYNCHRONIZE','2023-06-13-12:12:37','2023-06-13-14:39:58',1686651157,1686651157,1686651159,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',26380,'',0,14,0.0,0.0,'a00g_SYNCHRONIZE.20230613121553.out','a00g_SYNCHRONIZE.20230613121553.err',5,'a00g_REMOTE_SETUP','');
INSERT INTO job_data VALUES(18,2,'a00g_REMOTE_SETUP','2023-06-13-12:16:54','2023-06-13-14:40:13',1686651414,1686651501,0,'FAILED',2,48,'00:30','debug',0,'','REMOTE_SETUP','',0,0,'LUMI-LOGIN',3685602,'',0,14,0.0,0.0,'','',0,'a00g_19900101_fc0_INI','');
INSERT INTO job_data VALUES(19,2,'a00g_19900101_fc0_1_SIM','2023-06-13-12:26:17','2023-06-13-14:42:31',1686651420,1686651438,1686651438,'FAILED',16866496168521,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,0,'LUMI',3685603,'',0,15,0.0,0.0,'','',5,'a00g_19900101_fc0_2_SIM','');
INSERT INTO job_data VALUES(20,3,'a00g_LOCAL_SETUP','2023-06-13-14:39:18','2023-06-13-14:39:30',1686659864,1686659864,1686659869,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,1,'LOCAL',33597,'',0,16,0.0,0.0,'a00g_LOCAL_SETUP.20230613143930.out','a00g_LOCAL_SETUP.20230613143930.err',5,'a00g_SYNCHRONIZE','');
INSERT INTO job_data VALUES(21,3,'a00g_SYNCHRONIZE','2023-06-13-14:39:58','2023-06-13-14:40:10',1686659971,1686659971,1686659976,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,1,'LOCAL',33737,'',0,16,0.0,0.0,'a00g_SYNCHRONIZE.20230613144010.out','a00g_SYNCHRONIZE.20230613144010.err',5,'a00g_REMOTE_SETUP','');
INSERT INTO job_data VALUES(22,3,'a00g_REMOTE_SETUP','2023-06-13-14:40:13','2023-06-13-14:42:27',1686660013,1686660014,1686660019,'COMPLETED',2,96,'00:30','debug',0,'','REMOTE_SETUP','',0,1,'LUMI-LOGIN',3686410,'',1,16,0.0,0.0,'a00g_REMOTE_SETUP.20230613144030.out','a00g_REMOTE_SETUP.20230613144030.err',2,'a00g_19900101_fc0_INI',replace('                  3686410  COMPLETED         96        1 2023-06-13T15:40:13 2023-06-13T15:40:13 2023-06-13T15:40:19                                                                    \n            3686410.batch  COMPLETED         96        1 2023-06-13T15:40:13 2023-06-13T15:40:13 2023-06-13T15:40:19              0                     2396K                     2396K \n','\n',char(10)));
INSERT INTO job_data VALUES(23,3,'a00g_19900101_fc0_INI','2023-06-13-14:40:48','2023-06-13-14:41:05',1686660048,1686660049,1686660054,'COMPLETED',2,48,'00:30','debug',0,'1990-01-01 00:00:00','INI','fc0',0,1,'LUMI-LOGIN',3686413,'',0,16,0.0,0.0,'a00g_19900101_fc0_INI.20230613144105.out','a00g_19900101_fc0_INI.20230613144105.err',5,'a00g_19900101_fc0_1_SIM','');
INSERT INTO job_data VALUES(24,3,'a00g_19900101_fc0_1_SIM','2023-06-13-14:42:31','2023-06-14-08:52:39',1686660151,1686660168,1686660173,'COMPLETED',2,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,0,'LUMI',3686421,'',0,16,0.0,0.0,'a00g_19900101_fc0_1_SIM.20230613144252.out','a00g_19900101_fc0_1_SIM.20230613144252.err',5,'','');
INSERT INTO job_data VALUES(25,4,'a00g_19900101_fc0_1_SIM','2023-06-14-08:52:39','2023-06-14-08:54:36',1686725517,1686725538,1686725543,'COMPLETED',16867255118946,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,0,'LUMI',3690246,'',0,21,0.0,0.0,'','',5,'a00g_19900101_fc0_2_SIM','');
INSERT INTO job_data VALUES(26,4,'a00g_19900101_fc0_4_SIM','2023-06-14-08:52:52','2023-06-14-08:55:05',1686725517,1686725554,1686725559,'COMPLETED',16867255118946,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',4,0,'LUMI',3690246,'',0,21,0.0,0.0,'','',5,'','');
INSERT INTO job_data VALUES(27,4,'a00g_19900101_fc0_2_SIM','2023-06-14-08:52:53','2023-06-14-08:54:50',1686725517,1686725543,1686725548,'COMPLETED',16867255118946,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',2,0,'LUMI',3690246,'',0,21,0.0,0.0,'','',5,'a00g_19900101_fc0_3_SIM','');
INSERT INTO job_data VALUES(28,4,'a00g_19900101_fc0_3_SIM','2023-06-14-08:52:54','2023-06-14-08:55:08',1686725517,1686725548,1686725554,'COMPLETED',16867255118946,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',3,0,'LUMI',3690246,'',0,21,0.0,0.0,'','',5,'a00g_19900101_fc0_4_SIM','');
INSERT INTO job_data VALUES(29,5,'a00g_19900101_fc0_1_SIM','2023-06-14-08:54:36','2023-06-14-08:59:17',1686725634,1686725657,1686725663,'COMPLETED',16867256279748,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,0,'LUMI',3690279,'',0,22,0.0,0.0,'','',3,'a00g_19900101_fc0_2_SIM',replace('                  3690279  COMPLETED        768        3 2023-06-14T09:53:54 2023-06-14T09:54:16 2023-06-14T09:54:38                                                                    \n            3690279.batch  COMPLETED        256        1 2023-06-14T09:54:16 2023-06-14T09:54:16 2023-06-14T09:54:38              0                     5000K                     5000K \n','\n',char(10)));
INSERT INTO job_data VALUES(30,5,'a00g_19900101_fc0_2_SIM','2023-06-14-08:54:50','2023-06-14-08:59:35',1686725634,1686725663,1686725668,'COMPLETED',16867256279748,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',2,0,'LUMI',3690279,'',0,22,0.0,0.0,'','',3,'a00g_19900101_fc0_3_SIM',replace('                  3690279  COMPLETED        768        3 2023-06-14T09:53:54 2023-06-14T09:54:16 2023-06-14T09:54:38                                                                    \n            3690279.batch  COMPLETED        256        1 2023-06-14T09:54:16 2023-06-14T09:54:16 2023-06-14T09:54:38              0                     5000K                     5000K \n','\n',char(10)));
INSERT INTO job_data VALUES(31,5,'a00g_19900101_fc0_4_SIM','2023-06-14-08:55:05','2023-06-14-08:59:34',1686725634,1686725673,1686725678,'COMPLETED',16867256279748,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',4,0,'LUMI',3690279,'',0,22,0.0,0.0,'','',3,'',replace('                  3690279  COMPLETED        768        3 2023-06-14T09:53:54 2023-06-14T09:54:16 2023-06-14T09:54:38                                                                    \n            3690279.batch  COMPLETED        256        1 2023-06-14T09:54:16 2023-06-14T09:54:16 2023-06-14T09:54:38              0                     5000K                     5000K \n','\n',char(10)));
INSERT INTO job_data VALUES(32,5,'a00g_19900101_fc0_3_SIM','2023-06-14-08:55:08','2023-06-14-08:59:34',1686725634,1686725668,1686725673,'COMPLETED',16867256279748,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',3,0,'LUMI',3690279,'',0,22,0.0,0.0,'','',3,'a00g_19900101_fc0_4_SIM',replace('                  3690279  COMPLETED        768        3 2023-06-14T09:53:54 2023-06-14T09:54:16 2023-06-14T09:54:38                                                                    \n            3690279.batch  COMPLETED        256        1 2023-06-14T09:54:16 2023-06-14T09:54:16 2023-06-14T09:54:38              0                     5000K                     5000K \n','\n',char(10)));
INSERT INTO job_data VALUES(33,6,'a00g_19900101_fc0_1_SIM','2023-06-14-08:59:17','2023-06-14-09:05:10',1686725899,1686725931,1686725937,'COMPLETED',16867258907968,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,0,'LUMI',3690302,'',0,23,0.0,0.0,'','',5,'a00g_19900101_fc0_2_SIM','');
INSERT INTO job_data VALUES(34,6,'a00g_19900101_fc0_3_SIM','2023-06-14-08:59:34','2023-06-14-09:13:03',1686725899,1686725943,1686725948,'COMPLETED',16867258907968,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',3,0,'LUMI',3690302,'',0,23,0.0,0.0,'','',5,'a00g_19900101_fc0_4_SIM','');
INSERT INTO job_data VALUES(35,6,'a00g_19900101_fc0_4_SIM','2023-06-14-08:59:34','2023-06-14-09:17:05',1686725899,1686725948,1686725953,'COMPLETED',16867258907968,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',4,0,'LUMI',3690302,'',0,23,0.0,0.0,'','',5,'','');
INSERT INTO job_data VALUES(36,6,'a00g_19900101_fc0_2_SIM','2023-06-14-08:59:35','2023-06-14-09:09:13',1686725899,1686725937,1686725943,'COMPLETED',16867258907968,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',2,0,'LUMI',3690302,'',0,23,0.0,0.0,'','',5,'a00g_19900101_fc0_3_SIM','');
INSERT INTO job_data VALUES(37,7,'a00g_19900101_fc0_1_SIM','2023-06-14-09:05:10','2023-06-14-09:06:11',1686726012,1686726047,1686726287,'COMPLETED',16867260029525,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',1,1,'LUMI',3690307,'',0,24,0.0,0.0,'','',3,'a00g_19900101_fc0_2_SIM',replace('                  3690307    RUNNING        768        3 2023-06-14T10:00:12 2023-06-14T10:00:46             Unknown                                                                    \n            3690307.batch    RUNNING        256        1 2023-06-14T10:00:46 2023-06-14T10:00:46             Unknown              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(38,7,'a00g_19900101_fc0_2_SIM','2023-06-14-09:09:14','2023-06-14-09:10:15',1686726012,1686726287,1686726527,'COMPLETED',16867260029525,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',2,1,'LUMI',3690307,'',0,24,0.0,0.0,'','',3,'a00g_19900101_fc0_3_SIM',replace('                  3690307    RUNNING        768        3 2023-06-14T10:00:12 2023-06-14T10:00:46             Unknown                                                                    \n            3690307.batch    RUNNING        256        1 2023-06-14T10:00:46 2023-06-14T10:00:46             Unknown              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(39,7,'a00g_19900101_fc0_3_SIM','2023-06-14-09:13:03','2023-06-14-09:14:04',1686726012,1686726527,1686726767,'COMPLETED',16867260029525,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',3,1,'LUMI',3690307,'',0,24,0.0,0.0,'','',3,'a00g_19900101_fc0_4_SIM',replace('                  3690307    RUNNING        768        3 2023-06-14T10:00:12 2023-06-14T10:00:46             Unknown                                                                    \n            3690307.batch    RUNNING        256        1 2023-06-14T10:00:46 2023-06-14T10:00:46             Unknown              0                                                     \n','\n',char(10)));
INSERT INTO job_data VALUES(40,7,'a00g_19900101_fc0_4_SIM','2023-06-14-09:17:05','2023-06-14-09:17:05',1686726012,1686726767,1686727007,'COMPLETED',16867260029525,48,'00:20','debug',0,'1990-01-01 00:00:00','SIM','fc0',4,1,'LUMI',3690307,'',0,24,0.0,0.0,'','',5,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',28);
INSERT INTO sqlite_sequence VALUES('job_data',40);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
